
XEP-0447: Stateless File Sharing
================================

.. module:: slixmpp.plugins.xep_0447

.. autoclass:: XEP_0447
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0447.stanza
    :members:
    :undoc-members:

